@@ -6,6 +6,8 @@ module Joiner
   end
 end
 
+require 'joiner/alias_tracker'
+require 'joiner/join_aliaser'
 require 'joiner/join_dependency'
 require 'joiner/joins'
 require 'joiner/path'
